@@ -19,6 +19,7 @@
 #include <aws/mediatailor/model/CdnConfiguration.h>
 #include <aws/mediatailor/model/DashConfiguration.h>
 #include <aws/mediatailor/model/HlsConfiguration.h>
+#include <aws/mediatailor/model/LivePreRollConfiguration.h>
 #include <aws/core/utils/memory/stl/AWSMap.h>
 #include <utility>
 
@@ -193,6 +194,32 @@ namespace Model
     inline GetPlaybackConfigurationResult& WithHlsConfiguration(HlsConfiguration&& value) { SetHlsConfiguration(std::move(value)); return *this;}
 
 
+    /**
+     * <p>The configuration for pre-roll ad insertion.</p>
+     */
+    inline const LivePreRollConfiguration& GetLivePreRollConfiguration() const{ return m_livePreRollConfiguration; }
+
+    /**
+     * <p>The configuration for pre-roll ad insertion.</p>
+     */
+    inline void SetLivePreRollConfiguration(const LivePreRollConfiguration& value) { m_livePreRollConfiguration = value; }
+
+    /**
+     * <p>The configuration for pre-roll ad insertion.</p>
+     */
+    inline void SetLivePreRollConfiguration(LivePreRollConfiguration&& value) { m_livePreRollConfiguration = std::move(value); }
+
+    /**
+     * <p>The configuration for pre-roll ad insertion.</p>
+     */
+    inline GetPlaybackConfigurationResult& WithLivePreRollConfiguration(const LivePreRollConfiguration& value) { SetLivePreRollConfiguration(value); return *this;}
+
+    /**
+     * <p>The configuration for pre-roll ad insertion.</p>
+     */
+    inline GetPlaybackConfigurationResult& WithLivePreRollConfiguration(LivePreRollConfiguration&& value) { SetLivePreRollConfiguration(std::move(value)); return *this;}
+
+
     /**
      * <p>The identifier for the playback configuration.</p>
      */
@@ -592,6 +619,8 @@ namespace Model
 
     HlsConfiguration m_hlsConfiguration;
 
+    LivePreRollConfiguration m_livePreRollConfiguration;
+
     Aws::String m_name;
 
     Aws::String m_playbackConfigurationArn;
